@@ -114,6 +114,7 @@ class Service(object):
     LIST_CREATION_PATH     = '/lists/json'
     LIST_RENAME_PATH       = '/lists/rename/json'
     LIST_APPENDING_PATH    = '/lists/append/json'
+    LIST_TAG_PATH          = '/list/tags/json'
     SAVEDQUERY_PATH        = '/savedqueries/xml'
     VERSION_PATH           = '/version/ws'
     RELEASE_PATH           = '/version/release'
@@ -421,19 +422,27 @@ class ResultObject(object):
         if isinstance(fld, Attribute):
             if name in self._data:
                 attr = self._data[name]
-        elif isinstance(fld, Collection):
-            if name in self._data:
-                attr = map(lambda x: ResultObject(x, fld.type_class), self._data[name])
-            else:
-                attr = []
         elif isinstance(fld, Reference):
             if name in self._data:
-                attr = ResultObject(self._data[name], fld.type_class)
+                data = self._data[name]
+            else:
+                data = self._fetch_reference(fld)
+            if isinstance(fld, Collection):
+                attr = map(lambda x: ResultObject(x, fld.type_class), data)
+            else: 
+                attr = ResultObject(data, fld.type_class)
         else:
             raise WebserviceError("Inconsistent model - This should never happen")
         self._attr_cache[name] = attr
         return attr
-            
+
+    def _fetch_reference(self, fld):
+        q = self._cld.model.service.new_query(self._cld.name)
+        q.select("id", fld.name + ".*")
+        q.where("id", "=", self._data["objectId"])
+        q.outerjoin(fld.name)
+        return q.first()._data[fld.name]
+
 
 class ResultRow(object):
     """
@@ -444,11 +453,9 @@ class ResultRow(object):
     for convenience both list indexes and dictionary keys can be used. So the 
     following all work:
 
-        >>> # view is "Gene.symbol", "Gene.organism.name"
-       >>> row["symbol"]
-       >>> row["Gene.symbol"]
-       >>> row[0]
-       >>> row[:1]
+        >>> # Assuming the view is "Gene.symbol", "Gene.organism.name":
+        >>> row[0] == row["symbol"] == row["Gene.symbol"]
+        ... True 
 
     """
 
@@ -584,19 +591,13 @@ class ResultIterator(object):
         else:
             params.update({"format" : rowformat})
 
-        url  = root + path
-        data = urllib.urlencode(params)
-        con = opener.open(url, data)
-        self.reader = {
-            "tsv"         : lambda: FlatFileIterator(con, EchoParser()),
-            "csv"         : lambda: FlatFileIterator(con, EchoParser()),
-            "count"       : lambda: FlatFileIterator(con, EchoParser()),
-            "list"        : lambda: JSONIterator(con, ListValueParser()),
-            "rr"          : lambda: JSONIterator(con, ResultRowParser(view)),
-            "dict"        : lambda: JSONIterator(con, DictValueParser(view)),
-            "jsonobjects" : lambda: JSONIterator(con, ResultObjParser(cld)),
-            "jsonrows"    : lambda: JSONIterator(con, EchoParser())
-        }.get(rowformat)()
+        self.url  = root + path
+        self.data = urllib.urlencode(params)
+        self.view = view
+        self.opener = opener
+        self.cld = cld
+        self.rowformat = rowformat
+        self._it = None
 
     def __iter__(self):
         """
@@ -605,7 +606,18 @@ class ResultIterator(object):
 
         Returns the internal iterator object.
         """
-        return self.reader
+        con = self.opener.open(self.url, self.data)
+        reader = {
+            "tsv"         : lambda: FlatFileIterator(con, EchoParser()),
+            "csv"         : lambda: FlatFileIterator(con, EchoParser()),
+            "count"       : lambda: FlatFileIterator(con, EchoParser()),
+            "list"        : lambda: JSONIterator(con, ListValueParser()),
+            "rr"          : lambda: JSONIterator(con, ResultRowParser(self.view)),
+            "dict"        : lambda: JSONIterator(con, DictValueParser(self.view)),
+            "jsonobjects" : lambda: JSONIterator(con, ResultObjParser(self.cld)),
+            "jsonrows"    : lambda: JSONIterator(con, EchoParser())
+        }.get(self.rowformat)()
+        return reader
 
     def next(self):
         """
@@ -613,7 +625,13 @@ class ResultIterator(object):
         
         @rtype: whatever the rowformat was determined to be
         """
-        return self.reader.next()
+        if self._it is None:
+            self._it = iter(self)
+        try:
+            return self._it.next()
+        except StopIteration:
+            self._it = None
+            raise StopIteration
 
 class FlatFileIterator(object):
     """
